@@ -456,7 +456,7 @@ def getLogger(name=None, fname=False, clsname=False, fancyrecord=None):
     if not is_fancyroot():
         # deliberately not calling getRootLoggerName function to determine actual root logger name,
         # because it is prohibitively expensive in some texts (even when using 'python -O')
-        nameparts.append('root')
+        nameparts.append('fancyroot')
 
     if fancyrecord is None:
         # Altough we could set it as default value in the function definition
