@@ -612,12 +612,17 @@ class EasyConfigFormat(object):
             raise EasyBuildError('Invalid version number %s (incorrect length)', self.VERSION)
 
         self.rawtext = None  # text version of the easyconfig
-        self.comments = {}  # comments in easyconfig file
+        self._comments = {}  # comments in easyconfig file
         self.header = None  # easyconfig header (e.g., format version, license, ...)
         self.docstring = None  # easyconfig docstring (e.g., author, maintainer, ...)
 
         self.specs = {}
 
+    @property
+    def comments(self):
+        """Return comments in easyconfig file"""
+        return self._comments
+
     def set_specifications(self, specs):
         """Set specifications."""
         self.log.debug('Set copy of specs %s' % specs)
