@@ -53,8 +53,9 @@ from easybuild.framework.easyconfig.style import cmdline_easyconfigs_style_check
 from easybuild.tools.build_log import EasyBuildError, print_msg, print_warning
 from easybuild.tools.config import build_option
 from easybuild.tools.environment import restore_env
-from easybuild.tools.filetools import find_easyconfigs, is_patch_file, read_file, resolve_path, which, write_file
-from easybuild.tools.github import fetch_easyconfigs_from_pr, download_repo
+from easybuild.tools.filetools import find_easyconfigs, is_patch_file, locate_files
+from easybuild.tools.filetools import read_file, resolve_path, which, write_file
+from easybuild.tools.github import fetch_easyconfigs_from_pr, fetch_files_from_pr, download_repo
 from easybuild.tools.multidiff import multidiff
 from easybuild.tools.py2vs3 import OrderedDict
 from easybuild.tools.toolchain.toolchain import is_system_toolchain
@@ -348,44 +349,13 @@ def det_easyconfig_paths(orig_paths):
             ec_files = [path for path in pr_files if path.endswith('.eb')]
 
     if ec_files and robot_path:
-        # look for easyconfigs with relative paths in robot search path,
-        # unless they were found at the given relative paths
+        ignore_subdirs = build_option('ignore_dirs')
+        if not build_option('consider_archived_easyconfigs'):
+            ignore_subdirs.append(EASYCONFIGS_ARCHIVE_DIR)
 
-        # determine which easyconfigs files need to be found, if any
-        ecs_to_find = []
-        for idx, ec_file in enumerate(ec_files):
-            if ec_file == os.path.basename(ec_file) and not os.path.exists(ec_file):
-                ecs_to_find.append((idx, ec_file))
-        _log.debug("List of easyconfig files to find: %s" % ecs_to_find)
+        ec_files = locate_files(ec_files, robot_path, ignore_subdirs=ignore_subdirs)
 
-        # find missing easyconfigs by walking paths in robot search path
-        for path in robot_path:
-            _log.debug("Looking for missing easyconfig files (%d left) in %s..." % (len(ecs_to_find), path))
-            for (subpath, dirnames, filenames) in os.walk(path, topdown=True):
-                for idx, orig_path in ecs_to_find[:]:
-                    if orig_path in filenames:
-                        full_path = os.path.join(subpath, orig_path)
-                        _log.info("Found %s in %s: %s" % (orig_path, path, full_path))
-                        ec_files[idx] = full_path
-                        # if file was found, stop looking for it (first hit wins)
-                        ecs_to_find.remove((idx, orig_path))
-
-                # stop os.walk insanity as soon as we have all we need (os.walk loop)
-                if not ecs_to_find:
-                    break
-
-                # ignore subdirs specified to be ignored by replacing items in dirnames list used by os.walk
-                dirnames[:] = [d for d in dirnames if d not in build_option('ignore_dirs')]
-
-                # ignore archived easyconfigs, unless specified otherwise
-                if not build_option('consider_archived_easyconfigs'):
-                    dirnames[:] = [d for d in dirnames if d != EASYCONFIGS_ARCHIVE_DIR]
-
-            # stop os.walk insanity as soon as we have all we need (outer loop)
-            if not ecs_to_find:
-                break
-
-    return [os.path.abspath(ec_file) for ec_file in ec_files]
+    return ec_files
 
 
 def parse_easyconfigs(paths, validate=True):
@@ -728,3 +698,65 @@ def avail_easyblocks():
                                        easyblock_mod_name, easyblocks[easyblock_mod_name]['loc'], path)
 
     return easyblocks
+
+
+def det_copy_ec_specs(orig_paths, from_pr):
+    """Determine list of paths + target directory for --copy-ec."""
+
+    target_path, paths = None, []
+
+    # if only one argument is specified, use current directory as target directory
+    if len(orig_paths) == 1:
+        target_path = os.getcwd()
+        paths = orig_paths[:]
+
+    # if multiple arguments are specified, assume that last argument is target location,
+    # and remove that from list of paths to copy
+    elif orig_paths:
+        target_path = orig_paths[-1]
+        paths = orig_paths[:-1]
+
+    # if --from-pr was used in combination with --copy-ec, some extra care must be taken
+    if from_pr:
+        # pull in the paths to all the changed files in the PR,
+        # which includes easyconfigs but also patch files (& maybe more);
+        # do this in a dedicated subdirectory of the working tmpdir,
+        # to avoid potential trouble with already existing files in the working tmpdir
+        # (note: we use a fixed subdirectory in the working tmpdir here rather than a unique random subdirectory,
+        #  to ensure that the caching for fetch_files_from_pr works across calls for the same PR)
+        tmpdir = os.path.join(tempfile.gettempdir(), 'fetch_files_from_pr_%s' % from_pr)
+        pr_paths = fetch_files_from_pr(pr=from_pr, path=tmpdir)
+
+        # assume that files need to be copied to current working directory for now
+        target_path = os.getcwd()
+
+        if orig_paths:
+            last_path = orig_paths[-1]
+
+            # check files touched by PR and see if the target directory for --copy-ec
+            # corresponds to the name of one of these files;
+            # if so we should copy the specified file(s) to the current working directory,
+            # since interpreting the last argument as target location is very unlikely to be correct in this case
+            pr_filenames = [os.path.basename(p) for p in pr_paths]
+            if last_path in pr_filenames:
+                paths = orig_paths[:]
+            else:
+                target_path = last_path
+                # exclude last argument that is used as target location
+                paths = orig_paths[:-1]
+
+        # if list of files to copy is empty at this point,
+        # we simply copy *all* files touched by the PR
+        if not paths:
+            paths = pr_paths
+
+        # replace path for files touched by PR (no need to worry about others)
+        for idx, path in enumerate(paths):
+            filename = os.path.basename(path)
+            pr_matches = [x for x in pr_paths if os.path.basename(x) == filename]
+            if len(pr_matches) == 1:
+                paths[idx] = pr_matches[0]
+            elif pr_matches:
+                raise EasyBuildError("Found multiple paths for %s in PR: %s", filename, pr_matches)
+
+    return paths, target_path
