@@ -27,7 +27,9 @@ Support for BLIS as toolchain linear algebra library.
 
 :author: Kenneth Hoste (Ghent University)
 :author: Bart Oldeman (McGill University, Calcul Quebec, Compute Canada)
+:author: Sebastian Achilles (Forschungszentrum Juelich GmbH)
 """
+from distutils.version import LooseVersion
 
 from easybuild.tools.toolchain.linalg import LinAlg
 
@@ -42,3 +44,14 @@ class Blis(LinAlg):
     BLAS_MODULE_NAME = ['BLIS']
     BLAS_LIB = ['blis']
     BLAS_FAMILY = TC_CONSTANT_BLIS
+
+    def _set_blas_variables(self):
+        """AMD's fork with version number > 2.1 names the MT library blis-mt, while vanilla BLIS doesn't."""
+
+        # This assumes that AMD's BLIS has ver > 2.1 and vanilla BLIS < 2.1
+
+        found_version = self.get_software_version(self.BLAS_MODULE_NAME)[0]
+        if LooseVersion(found_version) > LooseVersion('2.1'):
+            self.BLAS_LIB_MT = ['blis-mt']
+
+        super(Blis, self)._set_blas_variables()
