@@ -101,6 +101,7 @@ DEFAULT_PKG_RELEASE = '1'
 DEFAULT_PKG_TOOL = PKG_TOOL_FPM
 DEFAULT_PKG_TYPE = PKG_TYPE_RPM
 DEFAULT_PNS = 'EasyBuildPNS'
+DEFAULT_PR_TARGET_ACCOUNT = 'easybuilders'
 DEFAULT_PREFIX = os.path.join(os.path.expanduser('~'), ".local", "easybuild")
 DEFAULT_REPOSITORY = 'FileRepository'
 DEFAULT_WAIT_ON_LOCK_INTERVAL = 60
@@ -184,6 +185,7 @@ BUILD_OPTIONS_CMDLINE = {
         'group',
         'hooks',
         'ignore_dirs',
+        'include_easyblocks_from_pr',
         'job_backend_config',
         'job_cores',
         'job_deps_type',
@@ -203,7 +205,6 @@ BUILD_OPTIONS_CMDLINE = {
         'pr_branch_name',
         'pr_commit_msg',
         'pr_descr',
-        'pr_target_account',
         'pr_target_repo',
         'pr_title',
         'rpath_filter',
@@ -252,6 +253,7 @@ BUILD_OPTIONS_CMDLINE = {
         'sequential',
         'set_gid_bit',
         'skip_test_cases',
+        'skip_test_step',
         'generate_devel_module',
         'sticky_bit',
         'trace',
@@ -306,6 +308,9 @@ BUILD_OPTIONS_CMDLINE = {
     DEFAULT_PKG_TYPE: [
         'package_type',
     ],
+    DEFAULT_PR_TARGET_ACCOUNT: [
+        'pr_target_account',
+    ],
     GENERAL_CLASS: [
         'suffix_modules_path',
     ],
