@@ -33,6 +33,7 @@ import base64
 import copy
 import getpass
 import glob
+import functools
 import os
 import random
 import re
@@ -50,7 +51,7 @@ from easybuild.framework.easyconfig.easyconfig import process_easyconfig
 from easybuild.framework.easyconfig.parser import EasyConfigParser
 from easybuild.tools.build_log import EasyBuildError, print_msg, print_warning
 from easybuild.tools.config import build_option
-from easybuild.tools.filetools import apply_patch, change_dir, copy_dir, copy_easyblocks, copy_framework_files
+from easybuild.tools.filetools import apply_patch, copy_dir, copy_easyblocks, copy_framework_files
 from easybuild.tools.filetools import det_patched_files, download_file, extract_file
 from easybuild.tools.filetools import get_easyblock_class_name, mkdir, read_file, symlink, which, write_file
 from easybuild.tools.py2vs3 import HTTPError, URLError, ascii_letters, urlopen
@@ -249,6 +250,12 @@ def github_api_get_request(request_f, github_user=None, token=None, **kwargs):
     if token is None:
         token = fetch_github_token(github_user)
 
+    # if we don't have a GitHub token, don't pass username either;
+    # this makes sense for read-only actions like fetching files from PRs
+    if token is None:
+        _log.info("Not specifying username since no GitHub token is available for %s", github_user)
+        github_user = None
+
     url = request_f(RestClient(GITHUB_API_URL, username=github_user, token=token))
 
     try:
@@ -364,7 +371,6 @@ def download_repo(repo=GITHUB_EASYCONFIGS_REPO, branch='master', account=GITHUB_
     _log.debug("%s downloaded to %s, extracting now" % (base_name, path))
 
     base_dir = extract_file(target_path, path, forced=True, change_into_dir=False)
-    change_dir(base_dir)
     extracted_path = os.path.join(base_dir, extracted_dir_name)
 
     # check if extracted_path exists
@@ -377,17 +383,37 @@ def download_repo(repo=GITHUB_EASYCONFIGS_REPO, branch='master', account=GITHUB_
     return extracted_path
 
 
-def fetch_easyblocks_from_pr(pr, path=None, github_user=None):
-    """Fetch patched easyconfig files for a particular PR."""
-    return fetch_files_from_pr(pr, path, github_user, github_repo=GITHUB_EASYBLOCKS_REPO)
+def pr_files_cache(func):
+    """
+    Decorator to cache result of fetch_files_from_pr.
+    """
+    cache = {}
+
+    @functools.wraps(func)
+    def cache_aware_func(pr, path=None, github_user=None, github_account=None, github_repo=None):
+        """Retrieve cached result, or fetch files from PR & cache result."""
+        # cache key is combination of all function arguments (incl. optional ones)
+        key = (pr, github_account, github_repo, path)
+
+        if key in cache and all(os.path.exists(x) for x in cache[key]):
+            _log.info("Using cached value for fetch_files_from_pr for PR #%s (account=%s, repo=%s, path=%s)",
+                      pr, github_account, github_repo, path)
+            return cache[key]
+        else:
+            res = func(pr, path=path, github_user=github_user, github_account=github_account, github_repo=github_repo)
+            cache[key] = res
+            return res
+
+    # expose clear/update methods of cache + cache itself to wrapped function
+    cache_aware_func._cache = cache  # useful in tests
+    cache_aware_func.clear_cache = cache.clear
+    cache_aware_func.update_cache = cache.update
+
+    return cache_aware_func
 
 
-def fetch_easyconfigs_from_pr(pr, path=None, github_user=None):
-    """Fetch patched easyconfig files for a particular PR."""
-    return fetch_files_from_pr(pr, path, github_user, github_repo=GITHUB_EASYCONFIGS_REPO)
-
-
-def fetch_files_from_pr(pr, path=None, github_user=None, github_repo=None):
+@pr_files_cache
+def fetch_files_from_pr(pr, path=None, github_user=None, github_account=None, github_repo=None):
     """Fetch patched files for a particular PR."""
 
     if github_user is None:
@@ -410,7 +436,8 @@ def fetch_files_from_pr(pr, path=None, github_user=None, github_repo=None):
         # make sure path exists, create it if necessary
         mkdir(path, parents=True)
 
-    github_account = build_option('pr_target_account')
+    if github_account is None:
+        github_account = build_option('pr_target_account')
 
     if github_repo == GITHUB_EASYCONFIGS_REPO:
         easyfiles = 'easyconfigs'
@@ -496,6 +523,16 @@ def fetch_files_from_pr(pr, path=None, github_user=None, github_repo=None):
     return files
 
 
+def fetch_easyblocks_from_pr(pr, path=None, github_user=None):
+    """Fetch patched easyconfig files for a particular PR."""
+    return fetch_files_from_pr(pr, path, github_user, github_repo=GITHUB_EASYBLOCKS_REPO)
+
+
+def fetch_easyconfigs_from_pr(pr, path=None, github_user=None):
+    """Fetch patched easyconfig files for a particular PR."""
+    return fetch_files_from_pr(pr, path, github_user, github_repo=GITHUB_EASYCONFIGS_REPO)
+
+
 def create_gist(txt, fn, descr=None, github_user=None, github_token=None):
     """Create a gist with the provided text."""
 
@@ -1283,7 +1320,7 @@ def merge_pr(pr):
     pr_target_account = build_option('pr_target_account')
     pr_target_repo = build_option('pr_target_repo') or GITHUB_EASYCONFIGS_REPO
 
-    pr_data, pr_url = fetch_pr_data(pr, pr_target_account, pr_target_repo, github_user, full=True)
+    pr_data, _ = fetch_pr_data(pr, pr_target_account, pr_target_repo, github_user, full=True)
 
     msg = "\n%s/%s PR #%s was submitted by %s, " % (pr_target_account, pr_target_repo, pr, pr_data['user']['login'])
     msg += "you are using GitHub account '%s'\n" % github_user
@@ -1294,6 +1331,12 @@ def merge_pr(pr):
     force = build_option('force')
     dry_run = build_option('dry_run') or build_option('extended_dry_run')
 
+    if not dry_run:
+        if pr_data['merged']:
+            raise EasyBuildError("This PR is already merged.")
+        elif pr_data['state'] == GITHUB_STATE_CLOSED:
+            raise EasyBuildError("This PR is closed.")
+
     def merge_url(gh):
         """Utility function to fetch merge URL for a specific PR."""
         return gh.repos[pr_target_account][pr_target_repo].pulls[pr].merge
@@ -2130,7 +2173,13 @@ def fetch_pr_data(pr, pr_target_account, pr_target_repo, github_user, full=False
         else:
             return gh.repos[pr_target_account][pr_target_repo].pulls[pr]
 
-    status, pr_data = github_api_get_request(pr_url, github_user, **parameters)
+    try:
+        status, pr_data = github_api_get_request(pr_url, github_user, **parameters)
+    except HTTPError as err:
+        raise EasyBuildError("Failed to get data for PR #%d from %s/%s (%s)\n"
+                             "Please check PR #, account and repo.",
+                             pr, pr_target_account, pr_target_repo, err)
+
     if status != HTTP_STATUS_OK:
         raise EasyBuildError("Failed to get data for PR #%d from %s/%s (status: %d %s)",
                              pr, pr_target_account, pr_target_repo, status, pr_data)
