@@ -1,5 +1,5 @@
 # #
-# Copyright 2009-2019 Ghent University
+# Copyright 2009-2020 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -34,11 +34,10 @@ Generic support for dealing with repositories
 :author: Ward Poelmans (Ghent University)
 :author: Fotis Georgatos (Uni.Lu, NTUA)
 """
-from vsc.utils import fancylogger
-from vsc.utils.missing import get_subclasses
-
+from easybuild.base import fancylogger
 from easybuild.tools.build_log import EasyBuildError
-from easybuild.tools.utilities import import_available_modules
+from easybuild.tools.py2vs3 import string_type
+from easybuild.tools.utilities import get_subclasses, import_available_modules
 
 _log = fancylogger.getLogger('repository', fname=False)
 
@@ -148,7 +147,7 @@ def avail_repositories(check_useable=True):
 
     class_dict = dict([(x.__name__, x) for x in get_subclasses(Repository) if x.USABLE or not check_useable])
 
-    if not 'FileRepository' in class_dict:
+    if 'FileRepository' not in class_dict:
         raise EasyBuildError("avail_repositories: FileRepository missing from list of repositories")
 
     return class_dict
@@ -159,10 +158,10 @@ def init_repository(repository, repository_path):
     inited_repo = None
     if isinstance(repository, Repository):
         inited_repo = repository
-    elif isinstance(repository, basestring):
+    elif isinstance(repository, string_type):
         repo = avail_repositories().get(repository)
         try:
-            if isinstance(repository_path, basestring):
+            if isinstance(repository_path, string_type):
                 inited_repo = repo(repository_path)
             elif isinstance(repository_path, (tuple, list)) and len(repository_path) <= 2:
                 inited_repo = repo(*repository_path)
