@@ -1,5 +1,5 @@
 # #
-# Copyright 2012-2019 Ghent University
+# Copyright 2012-2020 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -35,9 +35,9 @@ Map values can be string with named templates
 :author: Kenneth Hoste (Ghent University)
 """
 
-from vsc.utils import fancylogger
-
+from easybuild.base import fancylogger
 from easybuild.tools.build_log import EasyBuildError
+from easybuild.tools.py2vs3 import string_type
 
 
 class ToolchainOptions(dict):
@@ -52,13 +52,12 @@ class ToolchainOptions(dict):
             @options: dict with options : tuple option_name and option_description
             @options_map: dict with a mapping between and option and a value
         """
-        if not options is None:
+        if options is not None:
             self._add_options(options)
 
-        if not options_map is None:
+        if options_map is not None:
             self._add_options_map(options_map)
 
-
     def _add_options(self, options):
         """Add actual options dict to self"""
         self.log.debug("Using toolchain options %s", options)
@@ -75,7 +74,7 @@ class ToolchainOptions(dict):
             map names starting with _opt_ are allowed without corresponding option
         """
         for name in options_map.keys():
-            if not name in self:
+            if name not in self:
                 if name.startswith('_opt_'):
                     self.log.devel("_add_options_map: no option with name %s defined, but allowed", name)
                 else:
@@ -87,7 +86,12 @@ class ToolchainOptions(dict):
         """Return option value"""
         value = self.get(name, None)
         if value is None and name not in self.options_map:
-            self.log.warning("option: option with name %s returns None" % name)
+            msg = "option: option with name %s returns None" % name
+            # Empty options starting with _opt_ are allowed, so don't warn
+            if name.startswith('_opt_'):
+                self.log.devel(msg)
+            else:
+                self.log.warning(msg)
             res = None
         elif name in self.options_map:
             res = self.options_map[name]
@@ -95,18 +99,18 @@ class ToolchainOptions(dict):
             if templatedict is None:
                 templatedict = {}
             templatedict.update({
-                                 'opt':name,
-                                 'value':value,
-                                })
+                'opt': name,
+                'value': value,
+            })
 
-            if isinstance(res, basestring):
+            if isinstance(res, string_type):
                 # allow for template
                 res = self.options_map[name] % templatedict
             elif isinstance(res, (list, tuple,)):
                 # allow for template per element
                 res = self.options_map[name]
-                for i in xrange(0, len(res)):
-                    res[i] = res[i] % templatedict
+                for idx, elem in enumerate(res):
+                    res[idx] = elem % templatedict
             else:
                 # check if True?
                 res = self.options_map[name]
