@@ -43,7 +43,7 @@ from easybuild.tools.config import build_option, module_classes
 from easybuild.tools.configobj import ConfigObj
 from easybuild.tools.filetools import read_file, write_file
 from easybuild.tools.github import VALID_CLOSE_PR_REASONS
-from easybuild.tools.testing import post_easyconfigs_pr_test_report, session_state
+from easybuild.tools.testing import post_pr_test_report, session_state
 from easybuild.tools.py2vs3 import HTTPError, URLError, ascii_letters
 import easybuild.tools.github as gh
 
@@ -126,13 +126,13 @@ class GithubTest(EnhancedTestCase):
             print("Skipping test_fetch_pr_data, no GitHub token available?")
             return
 
-        pr_data, pr_url = gh.fetch_pr_data(1, GITHUB_USER, GITHUB_REPO, GITHUB_TEST_ACCOUNT)
+        pr_data, _ = gh.fetch_pr_data(1, GITHUB_USER, GITHUB_REPO, GITHUB_TEST_ACCOUNT)
 
         self.assertEqual(pr_data['number'], 1)
         self.assertEqual(pr_data['title'], "a pr")
         self.assertFalse(any(key in pr_data for key in ['issue_comments', 'review', 'status_last_commit']))
 
-        pr_data, pr_url = gh.fetch_pr_data(2, GITHUB_USER, GITHUB_REPO, GITHUB_TEST_ACCOUNT, full=True)
+        pr_data, _ = gh.fetch_pr_data(2, GITHUB_USER, GITHUB_REPO, GITHUB_TEST_ACCOUNT, full=True)
         self.assertEqual(pr_data['number'], 2)
         self.assertEqual(pr_data['title'], "an open pr (do not close this please)")
         self.assertTrue(pr_data['issue_comments'])
@@ -327,6 +327,67 @@ class GithubTest(EnhancedTestCase):
             except URLError as err:
                 print("Ignoring URLError '%s' in test_fetch_easyconfigs_from_pr" % err)
 
+    def test_fetch_files_from_pr_cache(self):
+        """Test caching for fetch_files_from_pr."""
+        if self.skip_github_tests:
+            print("Skipping test_fetch_files_from_pr_cache, no GitHub token available?")
+            return
+
+        init_config(build_options={
+            'pr_target_account': gh.GITHUB_EB_MAIN,
+        })
+
+        # clear cache first, to make sure we start with a clean slate
+        gh.fetch_files_from_pr.clear_cache()
+        self.assertFalse(gh.fetch_files_from_pr._cache)
+
+        pr7159_filenames = [
+            'DOLFIN-2018.1.0.post1-foss-2018a-Python-3.6.4.eb',
+            'OpenFOAM-5.0-20180108-foss-2018a.eb',
+            'OpenFOAM-5.0-20180108-intel-2018a.eb',
+            'OpenFOAM-6-foss-2018b.eb',
+            'OpenFOAM-6-intel-2018a.eb',
+            'OpenFOAM-v1806-foss-2018b.eb',
+            'PETSc-3.9.3-foss-2018a.eb',
+            'SCOTCH-6.0.6-foss-2018a.eb',
+            'SCOTCH-6.0.6-foss-2018b.eb',
+            'SCOTCH-6.0.6-intel-2018a.eb',
+            'Trilinos-12.12.1-foss-2018a-Python-3.6.4.eb'
+        ]
+        pr7159_files = gh.fetch_easyconfigs_from_pr(7159, path=self.test_prefix, github_user=GITHUB_TEST_ACCOUNT)
+        self.assertEqual(sorted(pr7159_filenames), sorted(os.path.basename(f) for f in pr7159_files))
+
+        # check that cache has been populated for PR 7159
+        self.assertEqual(len(gh.fetch_files_from_pr._cache.keys()), 1)
+
+        # github_account value is None (results in using default 'easybuilders')
+        cache_key = (7159, None, 'easybuild-easyconfigs', self.test_prefix)
+        self.assertTrue(cache_key in gh.fetch_files_from_pr._cache.keys())
+
+        cache_entry = gh.fetch_files_from_pr._cache[cache_key]
+        self.assertEqual(sorted([os.path.basename(f) for f in cache_entry]), sorted(pr7159_filenames))
+
+        # same query should return result from cache entry
+        res = gh.fetch_easyconfigs_from_pr(7159, path=self.test_prefix, github_user=GITHUB_TEST_ACCOUNT)
+        self.assertEqual(res, pr7159_files)
+
+        # inject entry in cache and check result of matching query
+        pr_id = 12345
+        tmpdir = os.path.join(self.test_prefix, 'easyblocks-pr-12345')
+        pr12345_files = [
+            os.path.join(tmpdir, 'foo.py'),
+            os.path.join(tmpdir, 'bar.py'),
+        ]
+        for fp in pr12345_files:
+            write_file(fp, '')
+
+        # github_account value is None (results in using default 'easybuilders')
+        cache_key = (pr_id, None, 'easybuild-easyblocks', tmpdir)
+        gh.fetch_files_from_pr.update_cache({cache_key: pr12345_files})
+
+        res = gh.fetch_easyblocks_from_pr(12345, tmpdir)
+        self.assertEqual(sorted(pr12345_files), sorted(res))
+
     def test_fetch_latest_commit_sha(self):
         """Test fetch_latest_commit_sha function."""
         if self.skip_github_tests:
@@ -345,6 +406,8 @@ class GithubTest(EnhancedTestCase):
             print("Skipping test_download_repo, no GitHub token available?")
             return
 
+        cwd = os.getcwd()
+
         # default: download tarball for master branch of easybuilders/easybuild-easyconfigs repo
         path = gh.download_repo(path=self.test_prefix, github_user=GITHUB_TEST_ACCOUNT)
         repodir = os.path.join(self.test_prefix, 'easybuilders', 'easybuild-easyconfigs-master')
@@ -354,6 +417,9 @@ class GithubTest(EnhancedTestCase):
         self.assertTrue(re.match('^[0-9a-f]{40}$', read_file(shafile)))
         self.assertTrue(os.path.exists(os.path.join(repodir, 'easybuild', 'easyconfigs', 'f', 'foss', 'foss-2019b.eb')))
 
+        # current directory should not have changed after calling download_repo
+        self.assertTrue(os.path.samefile(cwd, os.getcwd()))
+
         # existing downloaded repo is not reperformed, except if SHA is different
         account, repo, branch = 'boegel', 'easybuild-easyblocks', 'develop'
         repodir = os.path.join(self.test_prefix, account, '%s-%s' % (repo, branch))
@@ -828,10 +894,10 @@ class GithubTest(EnhancedTestCase):
         regex = re.compile(pattern)
         self.assertTrue(regex.match(stdout.strip()), "Pattern '%s' doesn't match: %s" % (regex.pattern, stdout))
 
-    def test_post_easyconfigs_pr_test_report(self):
-        """Test for post_easyconfigs_pr_test_report function."""
+    def test_pr_test_report(self):
+        """Test for post_pr_test_report function."""
         if self.skip_github_tests:
-            print("Skipping test_post_easyconfigs_pr_test_report, no GitHub token available?")
+            print("Skipping test_post_pr_test_report, no GitHub token available?")
             return
 
         init_config(build_options={
@@ -839,14 +905,13 @@ class GithubTest(EnhancedTestCase):
             'github_user': GITHUB_TEST_ACCOUNT,
         })
 
-        test_report = os.path.join(self.test_prefix, 'test_report.txt')
-        write_file(test_report, "This is a test report!")
+        test_report = {'full': "This is a test report!"}
 
         init_session_state = session_state()
 
         self.mock_stderr(True)
         self.mock_stdout(True)
-        post_easyconfigs_pr_test_report('1234', test_report, "OK!", init_session_state, True)
+        post_pr_test_report('1234', gh.GITHUB_EASYCONFIGS_REPO, test_report, "OK!", init_session_state, True)
         stderr, stdout = self.get_stderr(), self.get_stdout()
         self.mock_stderr(False)
         self.mock_stdout(False)
@@ -861,6 +926,23 @@ class GithubTest(EnhancedTestCase):
             regex = re.compile(pattern, re.M)
             self.assertTrue(regex.search(stdout), "Pattern '%s' should be found in: %s" % (regex.pattern, stdout))
 
+        self.mock_stderr(True)
+        self.mock_stdout(True)
+        post_pr_test_report('1234', gh.GITHUB_EASYBLOCKS_REPO, test_report, "OK!", init_session_state, True)
+        stderr, stdout = self.get_stderr(), self.get_stdout()
+        self.mock_stderr(False)
+        self.mock_stdout(False)
+
+        self.assertEqual(stderr, '')
+
+        patterns = [
+            r"^\[DRY RUN\] Adding comment to easybuild-easyblocks issue #1234: 'Test report by @easybuild_test",
+            r"^See https://gist.github.com/DRY_RUN for a full test report.'",
+        ]
+        for pattern in patterns:
+            regex = re.compile(pattern, re.M)
+            self.assertTrue(regex.search(stdout), "Pattern '%s' should be found in: %s" % (regex.pattern, stdout))
+
 
 def suite():
     """ returns all the testcases in this module """
