@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # #
-# Copyright 2012-2019 Ghent University
+# Copyright 2012-2020 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -35,9 +35,9 @@ import os
 import sys
 import tempfile
 import unittest
-from vsc.utils import fancylogger
 
 # initialize EasyBuild logging, so we disable it
+from easybuild.base import fancylogger
 from easybuild.tools.build_log import EasyBuildError
 from easybuild.tools.options import set_tmpdir
 
@@ -70,7 +70,6 @@ import test.framework.package as pkg
 import test.framework.repository as r
 import test.framework.robot as robot
 import test.framework.run as run
-import test.framework.scripts as sc
 import test.framework.style as st
 import test.framework.systemtools as s
 import test.framework.toolchain as tc
@@ -88,13 +87,13 @@ try:
     import keyring
     from keyrings.alt.file import PlaintextKeyring
     keyring.set_keyring(PlaintextKeyring())
-except ImportError as err:
+except ImportError:
     try:
         # with old versions of keyring, PlaintextKeyring comes from keyring.backends
         import keyring
         from keyring.backends.file import PlaintextKeyring
         keyring.set_keyring(PlaintextKeyring())
-    except ImportError as err:
+    except ImportError:
         pass
 
 # disable all logging to significantly speed up tests
@@ -105,7 +104,7 @@ fancylogger.setLogLevelError()
 # make sure temporary files can be created/used
 try:
     set_tmpdir(raise_error=True)
-except EasyBuildError, err:
+except EasyBuildError as err:
     sys.stderr.write("No execution rights on temporary files, specify another location via $TMPDIR: %s\n" % err)
     sys.exit(1)
 
@@ -118,27 +117,17 @@ log = fancylogger.getLogger()
 
 # call suite() for each module and then run them all
 # note: make sure the options unit tests run first, to avoid running some of them with a readily initialized config
-tests = [gen, bl, o, r, ef, ev, ebco, ep, e, mg, m, mt, f, run, a, robot, b, v, g, tcv, tc, t, c, s, lic, f_c, sc,
+tests = [gen, bl, o, r, ef, ev, ebco, ep, e, mg, m, mt, f, run, a, robot, b, v, g, tcv, tc, t, c, s, lic, f_c,
          tw, p, i, pkg, d, env, et, y, st, h, ct, lib]
 
 SUITE = unittest.TestSuite([x.suite() for x in tests])
-
-# uses XMLTestRunner if possible, so we can output an XML file that can be supplied to Jenkins
-xml_msg = ""
-try:
-    import xmlrunner  # requires unittest-xml-reporting package
-    xml_dir = 'test-reports'
-    res = xmlrunner.XMLTestRunner(output=xml_dir, verbosity=1).run(SUITE)
-    xml_msg = ", XML output of tests available in %s directory" % xml_dir
-except ImportError, err:
-    sys.stderr.write("WARNING: xmlrunner module not available, falling back to using unittest...\n\n")
-    res = unittest.TextTestRunner().run(SUITE)
+res = unittest.TextTestRunner().run(SUITE)
 
 fancylogger.logToFile(log_fn, enable=False)
 
 if not res.wasSuccessful():
     sys.stderr.write("ERROR: Not all tests were successful.\n")
-    print "Log available at %s" % log_fn, xml_msg
+    print("Log available at %s" % log_fn)
     sys.exit(2)
 else:
     for fn in glob.glob('%s*' % log_fn):
